<?php

namespace App\Http\Controllers\backend;

use App\DataTables\backend\TerminalsDataTable;
use App\Http\Controllers\Controller;
use App\Models\Terminal;
use App\Services\AirportService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;

class TerminalController extends Controller
{
    public function __construct(private AirportService $airportService, private Terminal $model) { }
    /**
     * Display a listing of the resource.
     */
    public function index(TerminalsDataTable $dataTable)
    {
        $airports = $this->airportService->listAirports();

        $data = ['title' => 'Configure Terminal Information','airports' => $airports];
        return $dataTable->render('backend.terminal', $data);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        try {
            // Validate the request
            $request->validate(Terminal::$rules);

            $this->model->create([
                'terminal_name' => $request->name,
                'airport_id' => $request->airport_id,
                'terminal_status' =>  $request->status ?? true
            ]);

            // Return success response
            return response()->json([
                'message' => 'Terminal saved successfully!',
            ], 200); // HTTP 200 OK

        } catch (\Illuminate\Validation\ValidationException $e) {
            // Handle validation errors
            return response()->json([
                'message' => 'Validation failed.',
                'errors' => $e->errors(),
            ], 422); // HTTP 422 Unprocessable Entity

        } catch (\Exception $e) {
            // Log the error for debugging
            Log::error('Error saving terminal: ' . $e->getMessage());

            // Return a generic error message
            return response()->json([
                'message' => 'An error occurred while saving the terminal. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        try {
            // Fetch the company data by ID
            $terminal = $this->model->findOrFail($id);

            // Return the company data as JSON
            return response()->json($terminal);

        } catch (\Exception $e) {
            // Log the error for debugging
            Log::error('Error fetching terminal details: ' . $e->getMessage());

            // Return a generic error message
            return response()->json([
                'message' => 'An error occurred while fetching terminal details. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            $request->validate(Terminal::$rules);

            $terminal = $this->model->findOrFail($id); // Find the product by ID

            // Update product data
            $terminal->terminal_name = $request->name;
            $terminal->airport_id = $request->airport_id;
            $terminal->terminal_status = $request->status;
            $terminal->save();

            return response()->json([
                'message' => 'Terminal updated successfully!',
            ], 200); // HTTP 200 OK

        } catch (\Illuminate\Validation\ValidationException $e) {
            return response()->json([
                'message' => 'Validation failed.',
                'errors' => $e->errors(),
            ], 422); // HTTP 422 Unprocessable Entity

        } catch (\Exception $e) {
            Log::error('Error updating product: ' . $e->getMessage());
            return response()->json([
                'message' => 'An error occurred while updating the terminal. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        try {
            $terminal = $this->model->findOrFail($id); // Find the product by ID
            $terminal->delete(); // Soft delete the product

            return response()->json([
                'message' => 'Terminal deleted successfully!',
            ], 200); // HTTP 200 OK

        } catch (\Exception $e) {
            Log::error('Error deleting terminal: ' . $e->getMessage());
            return response()->json([
                'message' => 'An error occurred while deleting the terminal. Please try again.',
            ], 500); // HTTP 500 Internal Server Error
        }
    }
}
