<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class StoreBookingRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array
    {
        return [
            'customer.title' => 'required|string|max:50',
            'customer.first_name' => 'required|string|max:50',
            'customer.last_name' => 'required|string|max:50',
            'customer.email' => 'required|email|max:100',
//            'customer.email' => 'required|email|max:100|unique:customers,email',
//            'customer.mobile' => 'required|string|max:20|unique:customers,mobile',
            'customer.mobile' => 'required|string|max:20',
//            'customer.people' => 'required|string|max:20',
//            'customer.address' => 'required|string|max:255',


            'booking.terminal_details' => 'required|in:yes,no',
            'booking.departure_terminal' => 'exclude_if:booking.terminal_details,no|integer|exists:terminals,id',
            'booking.departure_flight_number' => 'exclude_if:booking.terminal_details,no|string|max:100',
            'booking.arrival_terminal' => 'exclude_if:booking.terminal_details,no|integer|exists:terminals,id',
            'booking.arrival_flight_number' => 'exclude_if:booking.terminal_details,no|string|max:100',

//            'vehicle' => 'required|array',
//            'vehicle.*.make' => 'required|string|max:100',
//            'vehicle.*.model' => 'required|string|max:100',
//            'vehicle.*.color' => 'required|string|max:50',
//            'vehicle.*.number' => 'required|string|max:20|unique:vehicles,number',
//
//            'check_agreed' => 'required|boolean',

//            'product_id' => 'required|exists:products,id',
//            'block_id' => 'required|exists:blocks,id',
//            'booking_date' => 'required|date',
//            'date_from' => 'required|date|after_or_equal:booking_date',
//            'date_to' => 'required|date|after_or_equal:date_from',
//            'dis_code' => 'nullable|string|max:20',
//            'pay_at_exit' => 'required|boolean',

//            'price' => 'required|numeric|min:0',
//            'net_price' => 'required|numeric|min:0',
//            'status' => 'required|in:pending,confirmed,canceled',
//            'payment_status' => 'required|in:pending,paid,failed',
//            'payment_ref' => 'nullable|string|max:100',
        ];
    }

    public function messages(): array
    {
        return [
            'customer.title.required' => 'Title is required',
            'customer.first_name.required' => 'First name is required',
            'customer.last_name.required' => 'Last name is required',
            'customer.email.required' => 'Email name is required',
            'customer.email' => 'Email must be a valid email address',

            'booking.departure_terminal' => 'Departure terminal is required',
            'booking.arrival_terminal' => 'Arrival terminal is required',
            'booking.departure_flight_number' => 'Departure flight number is required',
            'booking.arrival_flight_number' => 'Arrival flight number is required',
            'body.required' => 'A message is required',
        ];
    }
}
