<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Site extends Model
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array<string>
     */
    protected $fillable = [
        'name',
        'company_id',
        'airport_id',
    ];

    public static $rules = [
        'name' => 'required|string|max:150',
        'company_id' => 'required|exists:companies,id', // Ensure company_id exists in companies table
        'airport_id' => 'required|exists:airports,id',
    ];


    /**
     * Get the company that owns the site.
     *
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function company(): BelongsTo
    {
        return $this->belongsTo(Company::class);
    }

    /**
     * Get the airport associated with the site.
     *
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function airport(): BelongsTo
    {
        return $this->belongsTo(Airport::class);
    }

    /**
     * Scope a query to only include sites for a specific company.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @param int $companyId
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeForCompany($query, int $companyId)
    {
        return $query->where('company_id', $companyId);
    }

    /**
     * Scope a query to only include sites for a specific airport.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @param int $airportId
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeAtAirport($query, int $airportId)
    {
        return $query->where('airport_id', $airportId);
    }
}
