<?php

namespace App\Services;

use App\Models\Airport;
use App\Models\Booking;
use App\Models\Company;
use App\Models\Customer;
use App\Models\Invoice;
use App\Models\Payment;
use App\Models\Product;
use App\Models\Vehicle;
use Carbon\Carbon;

class BookingService
{
    private Company $company;
    private Vehicle $vehicle;
    private Customer $customer;
    private Product $product;
    private Airport $airport;
    private Booking $booking;
    private Invoice $invoice;

    public function __construct(Booking $booking, Company $company, Vehicle $vehicle, Customer $customer, Product $product, Airport $airport, Invoice $invoice)
    {
        $this->company = $company;
        $this->vehicle = $vehicle;
        $this->customer = $customer;
        $this->product = $product;
        $this->airport = $airport;
        $this->booking = $booking;
        $this->invoice = $invoice;
    }

    public function createBooking(array $data)
    {
        // Add any additional logic before creating the booking
        $booking =  Booking::create($data);
        return $this->formatBookingResponse($booking->id);
    }

    public function formatBookingResponse($booking_id): array
    {
        $booking = $this->booking::find($booking_id);
        $invoice = $this->invoice->where('booking_id', $booking_id)->first();

        //dd($booking);
        $bookingFormatted =  [
            'id' => $booking->id,
            'customer_id' => $booking->customer_id,
            'product_id' => $booking->product_id,
            'vehicle_id' => $booking->vehicle_id,
            'company_id' => $booking->company_id,
            'airport_id' => $booking->airport_id,
            'booking_date' => $booking->booking_date,
            'date_from' => Carbon::parse($booking->date_from)->format('Y-m-d'),
            'date_from_formatted' => Carbon::parse($booking->date_from)->isoFormat('MMM Do Y'),
            'date_fromtime' => Carbon::parse($booking->date_from)->format('H:ia'),
            'date_to' => Carbon::parse($booking->date_to)->format('Y-m-d'),
            'date_to_formatted' => Carbon::parse($booking->date_to)->isoFormat('MMM Do Y'),
            'date_totime' => Carbon::parse($booking->date_to)->format('H:ia'),
            'price' => $booking->price,
            'dis_code' => $booking->dis_code,
            'net_price' => $booking->net_price,
            'pay_at_exit' => $booking->pay_at_exit,

            'status' => $booking->status,
            'payment_status' => $booking->payment_status,
            'created_at' => $booking->created_at->format('Y-m-d H:iA'),
            'updated_at' => $booking->updated_at->format('Y-m-d H:iA'),
        ];


        $bookingFormatted['company'] = $this->company->formatResponse($booking->company);
        $bookingFormatted['vehicles'] = $this->vehicle->formatResponse($booking->vehicles);
        $bookingFormatted['customer'] = $this->customer->formatResponse($booking->customer);
        $bookingFormatted['product'] = $this->product->formatResponse($booking->product);
        $bookingFormatted['airport'] = $this->airport->formatResponse($booking->airport);
        if ($invoice) {
            $bookingFormatted['invoice'] = $this->invoice->formatResponse($invoice);
        }


        return $bookingFormatted;
    }

    public function updateBooking(int $id, array $data): ?Booking
    {
        $booking = Booking::find($id);

        if (!$booking) {
            return null;
        }

        $booking->update($data);
        return $booking;
    }

    public function cancelBooking(int $id): ?Booking
    {
        $booking = Booking::find($id);

        if (!$booking) {
            return null;
        }

        $booking->update(['status' => 'canceled']);
        return $booking;
    }

    public function getBookingById(int $id): ?Booking
    {
        return Booking::find($id);
    }

    public function listBookings(array $filters = [])
    {
        // Apply filters (e.g., date range, status, etc.)
        $query = Booking::query();

        if (isset($filters['customer_id'])) {
            $query->where('customer_id', $filters['customer_id']);
        }

        if (isset($filters['status'])) {
            $query->where('status', $filters['status']);
        }

        return $query->get();
    }
}
