<?php

namespace App\Services;

use App\Models\Booking;
use App\Models\Invoice;

class InvoiceService
{
    private Booking $booking;
    private Invoice $invoice;

    public function __construct(Booking $booking, Invoice $invoice)
    {
        $this->booking = $booking;
        $this->invoice = $invoice;
    }

    function generateInvoiceNumber()
    {
        $latest = $this->booking::latest()->first();
        $invoicePrefix = 'HPS-INV-';

        if (!$latest) {
            return $invoicePrefix.'0001';
        }

        $string = preg_replace("/[^0-9\.]/", '', $latest->id);

        return $invoicePrefix . sprintf('%04d', $string+1);
    }

    public function storeInvoice($data)
    {
        return $this->invoice->insert($data);
    }

    public function formatStoreData($data)
    {
        return [
            'invoice_no' => $this->generateInvoiceNumber(),
            'invoice_date' => $data['booking_date'],
            'type' => 'invoice',
            'status' => 'payment_pending',
            'company_id' => $data['company_id'],
            'customer_id' => $data['customer_id'],
            'booking_id' => $data['booking_id'],
            'amount' => $data['price'] ?? null,
            'discount' => $data['discount_amount'] ?? 0,
            'tax_amount' => $data['tax_amount'] ?? 0,
            'payment_method' => $data['payment_method'] ?? null,
            'payment_status' => $data['payment_status'] ?? null,
            'payment_date' => $data['payment_date'] ?? null,
            'payment_reference' => $data['payment_reference'] ?? null,
            'payment_currency' => $data['payment_currency'] ?? null,
            'payment_amount' => $data['payment_amount'] ?? 0,
            'total_amount' => $data['total_amount'] ?? 0,
        ];
    }
}
