<?php

namespace App\Services;

use App\Models\Product;
use App\Models\AirportProducts;
use App\Models\ProductFeature;
use App\Models\ProductServices;

class ProductService
{
    private Product $model;
    private AirportProducts $productAssignAirport;

    public function __construct(Product $product, AirportProducts $productAssignAirport)
    {
        $this->model = $product;
        $this->productAssignAirport = $productAssignAirport;
    }

    public function searchProducts(array $filters)
    {
        $query = $this->productAssignAirport::query();

        // Filter by airport_id
        if (isset($filters['airport'])) {
            $query->where('airport_id', $filters['airport']);
        }

        // Filter by company_id
        if (isset($filters['company'])) {
            $query->where('company_id', $filters['company']);
        }

        // Filter by price range
        if (isset($filters['price_min'])) {
            $query->where('price', '>=', $filters['price_min']);
        }
        if (isset($filters['price_max'])) {
            $query->where('price', '<=', $filters['price_max']);
        }

        // Filter by available quantity
        if (isset($filters['available_quantity_min'])) {
            $query->where('available_quantity', '>=', $filters['available_quantity_min']);
        }

        // Search by description (optional)
        if (isset($filters['description'])) {
            $query->where('description', 'like', '%' . $filters['description'] . '%');
        }

        // Execute the query and return results
        return $query->get()->map(function ($productAssignAirport) {
            return $this->formatAirportAssingData($productAssignAirport);
        })->chunk(4);
    }

    private function formatAirportAssingData($productAssignAirport)
    {
        $product = $productAssignAirport->product;
        $featureIds = json_decode($product->feature_ids) ?? [];
        $serviceIds = json_decode($product->service_ids) ?? [];
        $productFeatures = ProductFeature::whereIn('id',$featureIds)->get()->toArray();
        $proServices = ProductServices::whereIn('id',$serviceIds)->get()->toArray();

        return [
            'id' => $product->id,
            'company_id' => $product->company_id,
            'name' => $product->name,
            'subtitle' => $product->subtitle,
            'image' => $product->featured_image,
            'terms_and_conditions' => $product->terms_and_conditions,
            'drop_off_procedure' => $product->drop_off_procedure,
            'pick_up_procedure' => $product->pick_up_procedure,
            'min_dates' => $product->min_dates,
            'max_dates' => $product->max_dates,
            'description' => ['1','2'],

            'price' => $productAssignAirport->price,
            'available_quantity' => $productAssignAirport->available_quantity,
            'airport_id' => $productAssignAirport->airport_id,
            'airport_name' => $productAssignAirport->airport->name,
            'airport_address' => $productAssignAirport->airport->address,
            'airport_country' => $productAssignAirport->airport->country,
            'airport_latitude' => $productAssignAirport->airport->latitude,
            'airport_longitude' => $productAssignAirport->airport->longitude,

            'company_name' => $product->company->name,
            'company_address' => $product->company->address,
            'country' => $product->company->country,
            'currency' => $product->company->currency,
            'currency_symbol' => $product->company->currency_symbol,

            'features' => $productFeatures,
            'services' => $proServices,

        ];
    }

    public function bookParkingPackage($filters)
    {

    }

    public function getProductAssignAirportById(mixed $product, $airport)
    {
        $productAssignAirport = $this->productAssignAirport->where('product_id', $product)->where('airport_id', $airport)->where('is_active', '1')->first();
        return $this->formatAirportAssingData($productAssignAirport);
    }
}
