$(document).ready(function () {
    $('.select2').select2({
        theme: 'bootstrap-5'
    });

    // Initialize Date Range Picker
    $('#daterange').daterangepicker({
        locale: {
            format: 'YYYY-MM-DD'
        },
        startDate: moment().subtract(29, 'days'),
        endDate: moment()
    });

    // Initialize DataTable with Export and Column Toggle
    $('#booking_info').DataTable({
        responsive: true,  // Enable responsive behavior
        paging: true,
        searching: true,
        ordering: true,
        info: true,
        dom: "<'row'<'col-sm-12 col-md-4'l><'col-sm-12 col-md-4'B><'col-sm-12 col-md-4'f>>" +  // Custom layout for length menu, buttons, and search bar
            "<'row'<'col-sm-12'tr>>" +
            "<'row'<'col-sm-12 col-md-5'i><'col-sm-12 col-md-7'p>>",
        buttons: [
            {
                extend: 'csv',
                className: 'btn btn-sm'
            },
            {
                extend: 'excel',
                className: 'btn btn-sm'
            },
            {
                extend: 'print',
                className: 'btn btn-sm'
            },
            {
                extend: 'colvis',
                className: 'btn btn-sm'
            }
        ],
        lengthMenu: [10, 25, 50, 100],
        pageLength: 10
    });


    // Initialize DataTable
    var table = $('#bookings-table').DataTable({
        responsive: true,
        paging: true,
        searching: true,
        ordering: true,
        info: true,
        processing: true,
        dom: "<'row'<'col-sm-12 col-md-4'l><'col-sm-12 col-md-4'B><'col-sm-12 col-md-4'f>>" +  // Custom layout for length menu, buttons, and search bar
            "<'row'<'col-sm-12'tr>>" +
            "<'row'<'col-sm-12 col-md-5'i><'col-sm-12 col-md-7'p>>",
        buttons: [
            {
                extend: 'csv',
                className: 'btn btn-sm'
            },
            {
                extend: 'excel',
                className: 'btn btn-sm'
            },
            {
                extend: 'print',
                className: 'btn btn-sm'
            },
            {
                extend: 'colvis',
                className: 'btn btn-sm'
            }
        ],
        lengthMenu: [10, 25, 50, 100],
        pageLength: 10,
        columnDefs: [
            { responsivePriority: 1, targets: 0 },
            { responsivePriority: 2, targets: -1 }
        ],
        ajax: {
            url: bookingTblRoute, // Replace with your route
            type: "GET",
            data: function (d) {
                // Add filter values to the request
                d.product_id = $('#product-filter').val();
                d.date_filter_id = $('#date-filter').val();
                d.agent_id = $('#agent-filter').val();
                d.airport_id = $('#airport-filter').val();
                d.daterange = $('#daterange').val();
                d.terminal_id = $('#terminal-filter').val();
                d.payment_status = $('#payment-status-filter').val();
                d.search = $('#search-filter').val();

                // Add the date filter type and date range to the request
                var dateFilter = $('#date-filter').val();
                var dateRange = $('#daterange-filter').val();

                if (dateFilter && dateRange) {
                    d.date_filter_type = dateFilter; // Date filter type (e.g., Booking Date, Pick Date, Drop Date)
                    var dates = dateRange.split(' - ');
                    d.date_from = dates[0]; // Start date
                    d.date_to = dates[1];   // End date
                }
            }
        },
        columns: [
            { data: '#', name: '#', orderable: false, searchable: false }, // Row number column
            { data: 'company.name', name: 'company.name' }, // Company name
            { data: 'airport.name', name: 'airport.name' }, // Airport name
            { data: 'user_id', name: 'user_id' }, // User ID
            { data: 'customer.first_name', name: 'customer.first_name' }, // Customer first name
            { data: 'product.name', name: 'product.name' }, // Product name
            { data: 'block_name', name: 'block_name' }, // Block name
            { data: 'booking_date', name: 'booking_date' }, // Booking date
            { data: 'date_from', name: 'date_from' }, // Date from
            { data: 'date_to', name: 'date_to' }, // Date to
            { data: 'dis_code', name: 'dis_code' }, // Discount code
            { data: 'price', name: 'price' }, // Price
            { data: 'net_price', name: 'net_price' }, // Net price
            { data: 'status', name: 'status' }, // Status
            { data: 'pay_at_exit', name: 'pay_at_exit' }, // Pay at exit
            { data: 'payment_status', name: 'payment_status' }, // Payment status
            { data: 'payment_ref', name: 'payment_ref' }, // Payment reference
            { data: 'refunded', name: 'refunded' }, // Refunded
            { data: 'cancel_date', name: 'cancel_date' }, // Cancel date
            { data: 'cancel_reason', name: 'cancel_reason' }, // Cancel reason
            { data: 'delay_charge', name: 'delay_charge' }, // Delay charge
            { data: 'remarks', name: 'remarks' }, // Remarks
            { data: 'tax_amount', name: 'tax_amount' }, // Tax amount
            { data: 'discount_amount', name: 'discount_amount' }, // Discount amount
            { data: 'total_amount', name: 'total_amount' }, // Total amount
            { data: 'promotion_code', name: 'promotion_code' }, // Promotion code
            { data: 'action', name: 'action', orderable: false, searchable: false }
        ]
    });

    // Apply filters on button click
    $('#filter-form').on('submit', function(e) {
        e.preventDefault(); // Prevent the form from submitting
        table.ajax.reload(); // Reload DataTable with new filters
    });

    // Reset filters on button click
    $('#reset-filters').on('click', function () {
        // Clear all filter inputs
        $('#product-filter').val('').trigger('change');
        $('#date-filter').val('').trigger('change');
        $('#agent-filter').val('').trigger('change');
        $('#airport-filter').val('').trigger('change');
        $('#daterange').val('');
        $('#terminal-filter').val('').trigger('change');
        $('#payment-status-filter').val('').trigger('change');
        $('#search-filter').val('');

        // Reload DataTable without filters
        table.ajax.reload();
    });

    // Initialize Date Range Picker
    $('#daterange-filter').daterangepicker({
        autoUpdateInput: false, // Prevents automatic filling of the input field
        locale: {
            cancelLabel: 'Clear', // Add a clear button
            format: 'YYYY-MM-DD' // Set the date format
        }
    });

    // Update the input field when a date range is selected
    $('#daterange-filter').on('apply.daterangepicker', function(ev, picker) {
        $(this).val(picker.startDate.format('YYYY-MM-DD') + ' - ' + picker.endDate.format('YYYY-MM-DD'));
    });

    // Clear the input field when the clear button is clicked
    $('#daterange-filter').on('cancel.daterangepicker', function(ev, picker) {
        $(this).val('');
    });

    // Enable/disable date range input based on date filter selection
    $('#date-filter').on('change', function() {
        if ($(this).val()) {
            $('#daterange-filter').prop('disabled', false); // Enable date range input
        } else {
            $('#daterange-filter').prop('disabled', true); // Disable date range input
            $('#daterange-filter').val(''); // Clear the date range input
        }
    });
});
