$(document).ready(function () {
    var form = $('#productFeatureAdd');
    var loader = $('#addLoader');
    var isEditMode = false;
    var productFeatureId = null;

    // Function to handle form submission
    form.on('submit', function (e) {
        e.preventDefault(); // Prevent the default form submission

        if (isEditMode) {
            // Show the confirmation modal for update
            $('#confirmUpdateModal').modal('show');
        } else {
            // If not in edit mode, submit the form directly (create mode)
            submitForm();
        }
    });

    // Handle the confirmation button click
    $('#confirmUpdateButton').on('click', function () {
        $('#confirmUpdateModal').modal('hide'); // Hide the modal
        submitForm(); // Proceed with the form submission
    });

    function submitForm() {
        loader.addClass('active');
        var formData = new FormData(form[0]); // Create a FormData object

        if (isEditMode) {
            formData.append('_method', 'PUT'); // Override method to PUT
        }

        var url = isEditMode ? `/product_feature/${productFeatureId}` : productFeatureStoreRoute;
        var method = 'POST';

        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: url, // Route to handle the form submission
            type: method,
            data: formData,
            processData: false,
            contentType: false,
            success: function (response) {
                toastr.success(response.message);
                loader.removeClass('active');
                form[0].reset(); // Reset the form

                form.removeClass('was-validated');
                form.find('.form-control').removeClass('is-invalid');
                form.find('.form-control').removeClass('is-valid');

                $('#product-features-table').DataTable().ajax.reload();
            },
            error: function (xhr) {
                if (xhr.status === 422) {
                    var errors = xhr.responseJSON.errors;
                    if (errors) {
                        $.each(errors, function (key, value) {
                            toastr.error(value); // Display each error message
                        });
                    }
                } else {
                    // Handle generic errors
                    toastr.error(xhr.responseJSON.message || 'An error occurred. Please try again.');
                }
                loader.removeClass('active');
            }
        });
    }

    // Edit button click event
    $('#product-features-table').on('click', '.edit-product-feature-btn', function () {
        isEditMode = true; // Set edit mode to true
        productFeatureId = $(this).data('id'); // Get the company ID from the button

        // Fetch company data
        $.ajax({
            url: `/product_feature/${productFeatureId}/edit`,
            method: 'GET',
            success: function (response) {
                // Populate the form with the fetched data
                $('#title').val(response.title);
                $('#description').val(response.description);

                // Add a hidden input for company ID if it doesn't exist
                if (!$('#productFeatureId').length) {
                    form.append('<input type="hidden" id="productFeatureId" name="id" />');
                }
                $('#productFeatureId').val(productFeatureId); // Set the company ID in the hidden field

                // Scroll to the form
                $('html, body').animate({
                    scrollTop: $('#productFeatureAdd').offset().top
                }, 1000);
            },
            error: function (xhr) {
                toastr.error('An error occurred while fetching product details.');
            }
        });
    });

    var deleteProductFeatureId = null; // Variable to store the company ID for deletion

    // Delete button click event
    $('#product-features-table').on('click', '.delete-product-feature-btn', function () {
        deleteProductFeatureId = $(this).data('id'); // Get the company ID from the button
        $('#confirmDeleteModal').modal('show'); // Show the confirmation modal
    });

    // Handle the confirmation button click
    $('#confirmDeleteButton').on('click', function () {
        $('#confirmDeleteModal').modal('hide'); // Hide the modal

        // Send the delete request
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: `/product_feature/${deleteProductFeatureId}`, // Endpoint to delete the company
            type: 'DELETE',
            success: function (response) {
                toastr.success(response.message);
                $('#product-features-table').DataTable().ajax.reload(); // Reload the table
            },
            error: function (xhr) {
                toastr.error(xhr.responseJSON.message || 'An error occurred while deleting the company feature.');
            }
        });
    });
});
