$(document).ready(function () {
    var form = $('#terminalAdd');
    var loader = $('#addLoader');
    var isEditMode = false;
    var terminalId = null;

    // Function to handle form submission
    form.on('submit', function (e) {
        e.preventDefault(); // Prevent the default form submission

        if (isEditMode) {
            // Show the confirmation modal for update
            $('#confirmUpdateModal').modal('show');
        } else {
            // If not in edit mode, submit the form directly (create mode)
            submitForm();
        }
    });

    // Handle the confirmation button click
    $('#confirmUpdateButton').on('click', function () {
        $('#confirmUpdateModal').modal('hide'); // Hide the modal
        submitForm(); // Proceed with the form submission
    });

    function submitForm() {
        loader.addClass('active');
        var formData = new FormData(form[0]); // Create a FormData object

        if (isEditMode) {
            formData.append('_method', 'PUT'); // Override method to PUT
        }

        var url = isEditMode ? `/terminal/${terminalId}` : terminalStoreRoute;
        var method = 'POST';

        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: url, // Route to handle the form submission
            type: method,
            data: formData,
            processData: false,
            contentType: false,
            success: function (response) {
                toastr.success(response.message);
                loader.removeClass('active');
                form[0].reset(); // Reset the form

                form.removeClass('was-validated');
                form.find('.form-control').removeClass('is-invalid');
                form.find('.form-control').removeClass('is-valid');

                $('#terminals-table').DataTable().ajax.reload();
            },
            error: function (xhr) {
                if (xhr.status === 422) {
                    var errors = xhr.responseJSON.errors;
                    if (errors) {
                        $.each(errors, function (key, value) {
                            toastr.error(value); // Display each error message
                        });
                    }
                } else {
                    // Handle generic errors
                    toastr.error(xhr.responseJSON.message || 'An error occurred. Please try again.');
                }
                loader.removeClass('active');
            }
        });
    }

    // Edit button click event
    $('#terminals-table').on('click', '.edit-terminal-btn', function () {
        isEditMode = true;
        terminalId = $(this).data('id');

        // Fetch company data
        $.ajax({
            url: `/terminal/${terminalId}/edit`,
            method: 'GET',
            success: function (response) {
                // Populate the form with the fetched data
                $('#terminalName').val(response.terminal_name);
                $('#airport').val(response.airport_id);
                $('#status').val(response.terminal_status);

                // Add a hidden input for company ID if it doesn't exist
                if (!$('#terminalId').length) {
                    form.append('<input type="hidden" id="terminalId" name="id" />');
                }
                $('#terminalId').val(terminalId); // Set the company ID in the hidden field

                // Scroll to the form
                $('html, body').animate({
                    scrollTop: $('#terminalAdd').offset().top
                }, 1000);
            },
            error: function (xhr) {
                toastr.error('An error occurred while fetching terminal details.');
            }
        });
    });

    var deleteTerminalId = null;

    // Delete button click event
    $('#terminals-table').on('click', '.delete-terminal-btn', function () {
        deleteTerminalId = $(this).data('id');
        $('#confirmDeleteModal').modal('show');
    });

    // Handle the confirmation button click
    $('#confirmDeleteButton').on('click', function () {
        $('#confirmDeleteModal').modal('hide'); // Hide the modal

        // Send the delete request
        $.ajax({
            headers: {
                'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
            },
            url: `/terminal/${deleteTerminalId}`, // Endpoint to delete the company
            type: 'DELETE',
            success: function (response) {
                toastr.success(response.message);
                $('#terminals-table').DataTable().ajax.reload(); // Reload the table
            },
            error: function (xhr) {
                toastr.error(xhr.responseJSON.message || 'An error occurred while deleting the terminal.');
            }
        });
    });
});
