@extends('backend.layouts.app')

@section('title', $title)

@section('content')
    <div class="app-content-header">
        <div class="container-fluid">
            <div class="row">
                <div class="col-sm-6"><h3 class="mb-0">{{ ucwords($title) }}</h3></div>
            </div>
        </div>
    </div>
    <div class="app-content">
        <div class="container-fluid">
            <div class="row">
                <div class="col-12 col-sm-12 col-md-12">
                    <div class="card card-info card-outline mb-4">
                        <form class="needs-validation" novalidate method="POST" enctype="multipart/form-data" id="productAdd">
                            @csrf
                            <input type="hidden" id="productId" name="id" />
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-4">
                                        <label for="productName" class="form-label">Product name</label>
                                        <input
                                            type="text"
                                            class="form-control form-control-sm"
                                            id="productName"
                                            name="name"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>

                                    <div class="col-md-2">
                                        <label for="minDates" class="form-label">Minimum Dates</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="minDates"
                                            name="min_dates"
                                            required
                                            min="0"
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-2">
                                        <label for="maxDates" class="form-label">Maximum Dates</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="maxDates"
                                            name="max_dates"
                                            required
                                            min="0"
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>
                                    <div class="col-md-4">
                                        <label for="status" class="form-label">Company</label>
                                        <select class="form-select form-select-sm" id="company" name="company_id" required>
                                            <option selected value="">Select Company</option>
                                            @foreach($companies as $company)
                                                <option value="{{ $company->id }}">{{ $company->name }}</option>
                                            @endforeach
                                        </select>
                                        <div class="invalid-feedback">Please select a valid company.</div>
                                    </div>
                                    <div class="col-md-12">
                                        <span class="input-group-text">Description</span>
                                        <textarea class="form-control" id="description" name="description" required></textarea>
                                    </div>
                                    <div class="col-md-12">
                                        <span class="input-group-text">Drop-off Procedure</span>
                                        <textarea class="form-control form-control-sm" id="dropOffProcedure" name="drop_off_procedure" required></textarea>
                                    </div>
                                    <div class="col-md-12">
                                        <span class="input-group-text">Pick-up Procedure</span>
                                        <textarea class="form-control form-control-sm" id="pickUpProcedure" name="pick_up_procedure" required></textarea>
                                    </div>
                                    <div class="col-md-12">
                                        <span class="input-group-text">Terms And Conditions</span>
                                        <textarea class="form-control form-control-sm" id="termsAndConditions" name="terms_and_conditions" required></textarea>
                                    </div>
                                    <div class="col-md-12">
                                        <div class="input-group mb-3">
                                            <input type="file" class="form-control" name="featured_image" id="featuredImage" />
                                            <label class="input-group-text" for="featuredImage">Upload</label>
                                        </div>
                                    </div>
                                </div>

                                <div class="row g-3">
                                    <div class="col-md-3">
                                        <label for="airportId" class="form-label">Airport</label>
                                        <select class="form-select form-select-sm" id="airportId" name="airport_id" required>
                                            <option selected value="">Select Airport</option>
                                            @foreach($airports as $airport)
                                                <option value="{{ $airport->id }}">{{ $airport->name }}</option>
                                            @endforeach
                                        </select>
                                        <div class="invalid-feedback">Please select a valid airport.</div>
                                    </div>

                                    <div class="col-md-3">
                                        <label for="price" class="form-label">Price</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="price"
                                            name="price"
                                            step="0.01"
                                            min="0"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>

                                    <div class="col-md-3">
                                        <label for="quantity" class="form-label">Quantity</label>
                                        <input
                                            type="number"
                                            class="form-control form-control-sm"
                                            id="quantity"
                                            name="quantity"
                                            min="0"
                                            required
                                        />
                                        <div class="valid-feedback">Looks good!</div>
                                    </div>

                                    <div class="col-md-3">
                                        <label for="isActive" class="form-label">Status</label>
                                        <select class="form-select form-select-sm" id="isActive" name="is_active" required>
                                            <option selected value=1>Active</option>
                                            <option value=0>Deactive</option>
                                        </select>
                                        <div class="invalid-feedback">Please select a valid status.</div>
                                    </div>
                                </div>
                                <br>
                                <div class="row g-3">
                                    <div class="col-md-12">
                                        <select class="col-md-12 form-select form-select-sm select2" id="features" name="features[]" multiple="multiple" required>
                                            @foreach($features as $feature)
                                                <option value="{{ $feature->id }}" {{ in_array($feature->id, $selectedFeatures) ? 'selected' : '' }}>
                                                    {{ $feature->title }}
                                                </option>
                                            @endforeach
                                        </select>
                                    </div>
                                </div>
                            </div>

                            <div class="card-footer">
                                <button class="btn btn-info float-end" type="submit">Save</button>
                            </div>
                            <!-- Loader Overlay -->
                            <div class="card-overlay" id="addLoader">
                                <div class="spinner-border text-success" role="status">
                                    <span class="visually-hidden">Loading...</span>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

            <div class="row">
                <div class="col-md-12">
                    <div class="card mb-4">
                        <div class="card-body" style="overflow: auto;">
                            {{ $dataTable->table() }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <x-update-confirmation-modal
        message="Are you sure you want to update this product?"
    />
    <x-delete-confirmation-modal
        message="Are you sure you want to delete this product? This action cannot be undone."
    />
@endsection

@push('scripts')
    <script>
        const productStoreRoute = "{{ route('product.store') }}";
    </script>
    <script src="{{ asset('js/settings/setting.js') }}"></script>
    <script src="{{ asset('js/settings/product.js') }}"></script>
    {{ $dataTable->scripts(attributes: ['type' => 'module']) }}
    <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
@endpush

@push('styles')
    <link rel="stylesheet" href="{{ asset('css/datatables-custom.css') }}" />
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
@endpush

