<?php

use App\Http\Controllers\AboutController;
use App\Http\Controllers\backend\BookingAdminController;
use App\Http\Controllers\backend\DashboardAdminController;
use App\Http\Controllers\BookingController;

use App\Http\Controllers\ContactController;
use App\Http\Controllers\FaqController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\LegalController;
use App\Http\Controllers\OfferController;
use App\Http\Controllers\PaymentController;
use App\Http\Controllers\FrsProductController;
use App\Http\Controllers\StripeWebhookController;
use App\Http\Controllers\VehicleController;
use App\Http\Controllers\Auth\RegisteredUserController;

use App\Http\Controllers\backend\AirportController AS BckAirportController;
use App\Http\Controllers\backend\BlockController AS BckBlockController;
use App\Http\Controllers\backend\CompanyController AS BckCompanyController;
use App\Http\Controllers\backend\ProductController AS BckProductController;
use App\Http\Controllers\backend\SiteController AS BckSiteController;
use App\Http\Controllers\backend\TerminalController AS BckTerminalController;
use App\Http\Controllers\backend\ProductFeatureController AS BckProductFeatureController;
use App\Http\Controllers\backend\ProductServicesController AS BckProductServicesController;

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ProfileController;

// Main Pages
Route::get('/', [HomeController::class, 'index'])->name('home');
Route::get('/what-we-offer', [OfferController::class, 'index'])->name('what-we-offer');
Route::get('/faq', [FaqController::class, 'index'])->name('faq');
Route::get('/about', [AboutController::class, 'index'])->name('about');

// Contact
Route::get('/contact', [ContactController::class, 'index'])->name('contact');
Route::post('/contact', [ContactController::class, 'store'])->name('contact.store');

// Legal Pages
Route::get('/terms-and-conditions', [LegalController::class, 'terms'])->name('terms-and-conditions');
Route::get('/privacy-policy', [LegalController::class, 'privacy'])->name('privacy-policy');

// Search Functionality
//Route::post('/search', [HomeController::class, 'search'])->name('search');
//Route::post('/search', [FrsProductController::class, 'search'])->name('search');
Route::get('/search', [FrsProductController::class, 'search'])->name('product.search');// Search
Route::get('/booking', [BookingController::class, 'create'])->name('product.booking');// Search
Route::post('/booking', [BookingController::class, 'store'])->name('booking.create');// Search
Route::get('/payment/{booking_id}', [BookingController::class, 'payment'])->name('booking.payment');// Search

Route::get('/vehicle-models/{make}', [VehicleController::class, 'getVehicleModels']);

Route::post('/stripe/customer', [PaymentController::class, 'createCustomer'])->name('stripe.customer');
Route::post('/stripe/payment-intent', [PaymentController::class, 'createPaymentIntent'])->name('stripe.payment');
Route::post('/stripe/webhook', [PaymentController::class, 'handle'])->name('stripe.webhook');

Route::post('/checkout', [PaymentController::class, 'createCheckoutSession'])->name('stripe.checkout');
Route::get('/checkout-success', [PaymentController::class, 'checkoutSuccess'])->name('stripe.checkout.success');
Route::get('/checkout-cancel', [PaymentController::class, 'checkoutCancel'])->name('stripe.checkout.cancel');


Route::prefix('v1/bookings')->group(function () {
    Route::get('/', [BookingController::class, 'index']);              // List bookings
    Route::post('/', [BookingController::class, 'store']);             // Create a booking
    Route::get('{id}', [BookingController::class, 'show']);            // Get booking details
    Route::put('{id}', [BookingController::class, 'update']);          // Update booking
    Route::delete('{id}', [BookingController::class, 'cancel']);       // Cancel booking
});

// Fallback for 404
Route::fallback(function () {
    return view('errors.404');
});

// Restrict registration route
Route::middleware('auth')->group(function () {
    Route::get('/register-user', [RegisteredUserController::class, 'create'])->name('register.user');
    Route::post('/register-user', [RegisteredUserController::class, 'store'])->name('register.user.store');
});

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

    //Settings
    Route::resource('product', BckProductController::class);
    Route::resource('company', BckCompanyController::class);
    Route::resource('airport', BckAirportController::class);
    Route::resource('terminal', BckTerminalController::class);
    Route::resource('site', BckSiteController::class);
    Route::resource('block', BckBlockController::class);
    Route::resource('product_feature', BckProductFeatureController::class);
    Route::resource('product_service', BckProductServicesController::class);

    //Admin dashboard
    Route::get('/dashboard', [DashboardAdminController::class, 'commonDashboard'])->name('dashboard');
    Route::get('/common-dashboard', [DashboardAdminController::class, 'commonDashboard'])->name('dashboard.common');
    Route::get('/book-now', [BookingAdminController::class, 'bookNow'])->name('booking.now');
    Route::get('/book-now/{id}/edit', [BookingAdminController::class, 'edit'])->name('booking.edit');

    Route::post('/store-book-now', [BookingAdminController::class, 'storeBookNow'])->name('booking.store');
    Route::put('/book-now/{id}', [BookingAdminController::class, 'updateBookNow'])->name('booking.update');
});


Route::get('/bookings/datatable', [DashboardAdminController::class, 'datatable'])->name('bookings.datatable');
require __DIR__.'/auth.php';
